@@ -65,7 +65,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 report newretrieve newreport washn
 $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularratios @totalcases @winneritems);
 
-$VERSION = '0.96';
+$VERSION = '0.97';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -447,8 +447,6 @@ sub calcmiditers
 		my $countblock = 0;
 		foreach ( keys %$_ )
 		{
-
-
 			unless ( defined $mediumters[$countcase]{$_} )
 			{
 				$mediters[$countcase]{$_} = ( ceil( $varnumbers[$countcase]{$_} / 2 ) );
@@ -498,16 +496,10 @@ sub getblocks
 
 sub getblockelts
 { # IT GETS @blockelts. TO BE CALLED WITH getblockelts(\@sweeps, $countcase, $countblock)
-	my ( $sweeps_ref, $dowhat_ref, $countcase, $countblock ) = @_;
+	my ( $sweeps_ref, $countcase, $countblock ) = @_;
 	my @sweeps = @{ $sweeps_ref };
-	my %dowhat = %{ $dowhat_ref };
-	$dowhat{shadowdirection} = "no";
-	if ( $sweeps[$countcase][$countblock]->[0] =~ />/ )
-	{
-		$dowhat{shadowdirection} = "yes";
-	}
 	my @blockelts = sort { $a <=> $b } @{ $sweeps[$countcase][$countblock] };
-	return ( \@blockelts, \@sweeps, $dowhat{shadowdirection} );
+	return ( \@blockelts );
 }
 
 
@@ -849,6 +841,7 @@ sub cleansweeps
 			my @inbag;
 			foreach my $elt ( @{ $el } )
 			{
+				$elt =~ s/>// ;
 				$elt =~ s/[A-za-z]+//g ;
 				push( @inbag, $elt );
 			}
@@ -991,20 +984,6 @@ sub readsweeps
 }
 
 
-sub starrify
-{
-	my ( $dowhat_ref, $countcase, $countblock ) = @_;
-	my %dowhat = %{ $dowhat_ref }; #say $tee "IN STARRIFY \%dowhat: " . dump( \%dowhat );
-	if ( $dowhat{shadowdirection} eq "yes" )
-	{
-		$dowhat{newdirection} = $dowhat{direction}->[0]->[0]; #say $tee "IN STARRIFY \$dowhat{direction}: " . dump( $dowhat{direction} );
-		$dowhat{newstarorder} = $dowhat{starorder}->[0]->[0]; #say $tee "IN STARRIFY \$dowhat{starorder}: " . dump( $dowhat{starorder} );
-	} #say $tee "IN END STARRIFY \%dowhat: " . dump( %dowhat );
-	return( %dowhat );
-}
-
-
-
 sub stararrange
 {
 	my ( $sweeps_ref, $blockelts_ref, $varnumbers_ref, $countcase, $countblock, $file ) = @_;
@@ -1038,14 +1017,14 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	my %d = %{ $_[0] };
 	my $countcase = $d{countcase}; say $tee"IN callblock ( \$countcase) " . dump($countcase);
 	my $countblock = $d{countblock}; say $tee"IN callblock ( \$countblock) " . dump($countblock);
-	my @sweeps = @{ $d{sweeps} }; #say $tee"IN callblock \@sweeps " . dump(@sweeps);
-	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee"IN callblock \@sourcesweeps " . dump(@sourcesweeps);
-	my @miditers = @{ $d{miditers} }; #say $tee "IN callblock \@miditers " . dump( @miditers );
-	my @winneritems = @{ $d{winneritems} }; #say $tee "IN callblock \@winneritems " . dump( @winneritems );
+	my @sweeps = @{ $d{sweeps} }; say $tee"IN callblock \@sweeps " . dump(@sweeps);
+	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee"IN callblock \@sourcesweeps " . dump(@sourcesweeps);
+	my @miditers = @{ $d{miditers} }; say $tee "IN callblock \@miditers " . dump( @miditers );
+	my @winneritems = @{ $d{winneritems} }; say $tee "IN callblock \@winneritems " . dump( @winneritems );
 	my %dirfiles = %{ $d{dirfiles} }; #say $tee "IN callblock \%dirfiles " . dump( %dirfiles );
 	my %datastruc = %{ $d{datastruc} };
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN callblock \%dowhat" . dump( %dowhat );
-	my @varnumbers = @{ $d{varnumbers} }; #say $tee"IN callblock ( \@varnumbers) " . dump(@varnumbers);
+	my @varnumbers = @{ $d{varnumbers} }; say $tee"IN callblock ( \@varnumbers) " . dump( @varnumbers );
 
 	if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
@@ -1053,16 +1032,10 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
   }
 
 	my $rootname = getrootname(\@rootnames, $countcase);
-	( my $blockelts_ref, my $sweeps_ref, $dowhat{shadowdirection} ) = getblockelts( \@sweeps, \%dirfiles, $countcase, $countblock );
+	my @blockelts = @{ getblockelts( \@sweeps, $countcase, $countblock ) }; say $tee "IN callblock \@blockelts " . dump( @blockelts );
 
-	#say $tee "IN callblock \$dowhat{shadowdirection}" . dump( $dowhat{shadowdirection} );
-	my @blockelts = @{ $blockelts_ref }; say $tee "IN callblock \@blockelts " . dump( @blockelts );
-	my @sweeps = @{ $sweeps_ref }; #say $tee "IN callblock \@sweeps " . dump( @sweeps );
+	my @sourceblockelts = @{ getblockelts( \@sourcesweeps, $countcase, $countblock ) }; say $tee "IN callblock \@sourceblockelts " . dump( @sourceblockelts );
 
-	my ( $sourceblockelts_ref, $sourcesweeps_ref ) = getblockelts( \@sourcesweeps, \%dirfiles, $countcase, $countblock );
-
-	my @sourceblockelts = @{ $sourceblockelts_ref }; say $tee "IN callblock \@sourceblockelts " . dump( @sourceblockelts );
-	my @sourcesweeps = @{ $sourcesweeps_ref }; #say $tee "IN callblock \@sourcesweeps " . dump( @sourcesweeps );
 
 	my $entryname;
 	if ( $sourceblockelts[0] =~ /^([A-Za-z]+)/ )
@@ -1074,7 +1047,6 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	{
 		$dirfiles{entryname} = "";
 	} say $tee "IN callblock 2 \$entryname " . dump( $entryname );
-	#say $tee "IN callblock 2 \@sourceblockelts " . dump( @sourceblockelts );
 
 
 	my $exitname;
@@ -1087,34 +1059,96 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	{
 		$dirfiles{exitname} = "";
 	} say $tee "IN callblock 3 \$exitname " . dump( $exitname );
-	#say $tee "IN callblock 3 \@sourceblockelts " . dump( @sourceblockelts );
+
+
+	if ( $sourceblockelts[0] =~ /^(\d+)>/ )
+	{
+		$dirfiles{starsign} = "yes"; # FOR THE INNER STAR SEARCH
+		$dirfiles{stardivisions} =	my $entryname;
+	if ( $sourceblockelts[0] =~ /^([A-Za-z]+)/ )
+	{
+		$entryname = $1;
+		$dirfiles{entryname} = $entryname;
+	}
+	else
+	{
+		$dirfiles{entryname} = "";
+	} say $tee "IN callblock 2 \$entryname " . dump( $entryname ); $1;
+	}
+	else
+	{
+		$dirfiles{starsign} = "no";
+		$dirfiles{stardivisions} = "";
+	} say $tee "IN callblock 3 \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	say $tee "IN callblock 3 \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
+
 
 	my @blocks = getblocks( \@sweeps, $countcase );
 	my $toitem = getitem( \@winneritems, $countcase, $countblock );
 	my $from = getline($toitem);
-	my %varnums = getcase( \@varnumbers, $countcase ); #say $tee "IN callblock \%varnums" . dump( %varnums );
-	my %mids = getcase( \@miditers, $countcase ); #say $tee "IN callblock \%mids" . dump( %mids );
+	my %varnums = getcase( \@varnumbers, $countcase ); say $tee "IN callblock \%varnums" . dump( \%varnums );
+	my %mids = getcase( \@miditers, $countcase ); say $tee "IN callblock \%mids" . dump( \%mids );
 	my $file = $dowhat{file};
 
+
+	###########################################################
+
+
 	my @tempvarnumbers;
-	if ( $dowhat{shadowdirection} eq "yes" )
+	if ( $dirfiles{starsign} eq "yes" )
 	{
-		my $newvarnumbers_ref = stararrange( \@sweeps, \@blockelts, \@varnumbers, $countcase, $countblock, $file );
-		my @newvarnumbers = @{ $newvarnumbers_ref }; #say $tee "IN callblock IN shadowdirection \@newvarnumbers " . dump( @newvarnumbers );
-		$dowhat{varnumbershold} = dclone( \@varnumbers ); #say $tee "IN callblock IN shadowdirection \$dowhat{varnumbershold} " . dump( $dowhat{varnumbershold} );
-		@varnumbers = @{ dclone( \@newvarnumbers ) }; say $tee "IN callblock IN shadowdirection \@varnumbers " . dump( @varnumbers );
-
-		%dowhat = starrify( \%dowhat, $countcase, $countblock );
-		#say$tee "IN callblock \$dowhat{direction}[\$countcase][\$countblock] " . dump( $dowhat{direction}[$countcase][$countblock] );
-		#say $tee "IN callblock \$dowhat{starorder}[\$countcase][\$countblock] " . dump( $dowhat{starorder}[$countcase][$countblock] );
+		my @newvarnumbers = @{ stararrange( \@sweeps, \@blockelts, \@varnumbers, $countcase, $countblock, $file ) };
+		say $tee "IN callblock \@newvarnumbers " . dump( @newvarnumbers );
+		$dowhat{varnumbershold} = dclone( \@varnumbers ); say $tee "IN callblock  \$dowhat{varnumbershold} " . dump( $dowhat{varnumbershold} );
+		@varnumbers = @{ dclone( \@newvarnumbers ) }; say $tee "IN callblock dcloned \@varnumbers " . dump( @varnumbers );
 	}
-	#say $tee "IN callblock AFTER shadowdirection \$dowhat{varnumbershold} " . dump( $dowhat{varnumbershold} );
-	#say $tee "IN callblock AFTER shadowdirection \@varnumbers " . dump( @varnumbers );
 
 
+	sub solvestar
+	{
+		my %d = %{ $_[0] };
+		my %dirfiles = %{ $d{dirfiles} };
+		my %dowhat = %{ $d{dowhat} };
+		my @varnumbers = @{ $d{varnumbers} };
+
+		$dirfiles{direction} = "star";
+		$dirfiles{starorder} = $dowhat{starorder}->[countcase]->[0];
+
+		my ( @gencetres, @genextremes, @genpoints, $genextremes_ref, $gencentres_ref, @starpositions, @dummysweeps, @dummyblockelts );
+
+		if ( ( $dirfiles{stardivisions} ne "" ) and ( $dirfiles{starpositions} eq "" ) )
+		{
+			$dirfiles{starpositions} = genstar( \%dirfiles, \@varnumbers );
+
+			( $dirfiles{dummysweeps}, $dirfiles{dummyblockelts} ) = @{ someprocedure( \@sweeps, \@blockelts, \%countcase, \$countblock ) };
+		}
+
+		$dirfiles{starnumber} = scalar( @{ $dirfiles{starpositions} } ); say $tee "AFTER \$dowhat{starnumber}: " . dump( $dowhat{starnumber} );
+
+		if ( not( scalar( @{ $dirfiles{starpositions} } ) == 0 ) )
+		{
+			$dirfiles{direction} => [ [ "star" ] ],
+			$dirfiles{randomsweeps} => "no", # to randomize the order specified in @sweeps.
+			$dirfiles{randominit} => "no", # to randomize the init levels specified in @miditers.
+			$dirfiles{randomdirs} => "no", # to randomize the directions of descent.
+		}
+		return( { dirfiles => \%dirfiles } )
+	}
+
+
+	if ( $dirfiles{starsign} eq "yes" )
+	{
+		%dirfiles = %{ solvestar( { dirfiles => \%dirfiles, dowhat => \%dowhat, varnumbers => @varnumbers, \@sweeps } ) };
+	}
+
+
+
+
+  ###########################################################
+
 	$dirfiles{simlist} = "$mypath/$file-simlist--$countcase";
 	$dirfiles{morphlist} = "$mypath/$file-morphlist--$countcase";
-	$dirfiles{retlist} = "$mypath/$file-retlist--$countcase";
+	$dirfiles{retlist} = "$mypath/$file-retlist$dummysweeps_ref--$countcase";
 	$dirfiles{replist} = "$mypath/$file-replist--$countcase"; # # FOR RETRIEVAL
 	$dirfiles{descendlist} = "$mypath/$file-descendlist--$countcase"; # UNUSED FOR NOW
 	$dirfiles{simblock} = "$mypath/$file-simblock--$countcase-$countblock";
@@ -1128,8 +1162,7 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 	$dirfiles{ordres} = "$mypath/$file-$countcase" . "-ordres.csv"; #say "IN CALLBLOCK ordres:" . ( $dirfiles{ordres} ) . " .";
 
 	my $starstring = tellstring( \%mids, $file ); #say $tee "IN callblock \$starstring " . dump( $starstring );
-	$dirfiles{starstring} = $starstring;
-
+	$dirfiles{starstring} = $starstring; # FOR THE OUTTER STAR SEARCH
 
 	my $blockdata = {
 		countcase => $countcase, countblock => $countblock,
@@ -1137,14 +1170,37 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 		dirfiles => \%dirfiles,
 		sweeps => \@sweeps, sourcesweeps => \@sourcesweeps, datastruc => \%datastruc,
 		dowhat => \%dowhat, varnumbers => \@varnumbers };
-	deffiles( $blockdata );
+
+	if ( $dirfiles{starsign} eq "yes" )
+	{
+		my $d = 0;
+		foreach my $starmids_ref ( @{ $dirfiles{starpositions} } )
+		{
+			my $c = 0;
+			foreach $dummyblockelts_ref ( @{ $dirfiles{dummyblockelts} } )
+			{
+				deffiles( $blockdata, $starmids_ref, $d, $dummyblockelts_ref, $c );
+				$c++;
+			}
+		}
+		$d++;
+	}
+	else
+	{
+		deffiles( $blockdata ); say $tee "NOW IN";
+	}
 }
 
 sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 {
 	my %d = %{ $_[0] };
-	my $countcase = $d{countcase}; #say $tee "IN DEFFILES \$countcase : " . dump( $countcase );
-  my $countblock = $d{countblock}; #say $tee "IN DEFFILES \$countblock : " . dump( $countblock );
+	my $starmids_ref = $_[1];
+	$dirfiles{d} = $_[2];
+	my $dummyblockelts_ref = $_[3];
+	$dirfiles{c} = $_[4];
+
+	my $countcase = $d{countcase}; say $tee "IN DEFFILES \$countcase : " . dump( $countcase );
+  my $countblock = $d{countblock}; say $tee "IN DEFFILES \$countblock : " . dump( $countblock );
 	my @sweeps = @{ $d{sweeps} }; #say $tee "IN DEFFILES \@sweeps : " . dump( @sweeps );
 	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "IN DEFFILES \@sourcesweeps : " . dump( @sourcesweeps );
 	my @miditers = @{ $d{miditers} }; #say $tee "IN DEFFILES \@miditers : " . dump( @miditers );
@@ -1156,9 +1212,8 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 
 	my $rootname = getrootname( \@rootnames, $countcase ); #say $tee "\$rootname : " . dump( $rootname );
 
-	( my $blockelts_ref, my $sweeps_ref, $dirfiles{shadowdirection} ) = getblockelts(\@sweeps, \%dirfiles, $countcase, $countblock );
+	( my $blockelts_ref ) = getblockelts( \@sweeps, $countcase, $countblock );
 	my @blockelts = @{ $blockelts_ref };
-	@sweeps = @{ $sweeps_ref };
 
 	my @blocks = getblocks( \@sweeps, $countcase ); #say $tee "IN DEFFILES \@blocks : " . dump( @blocks );
 	my $toitem = getitem( \@winneritems, $countcase, $countblock ); #say $tee "IN DEFFILES \$toitem : " . dump( $toitem );
@@ -1167,12 +1222,24 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 
 
 	my %varnums = getcase( \@varnumbers, $countcase ); #say $tee "IN DEFFILES \%varnums" . dump( %varnums );
+
 	my %mids = getcase(\@miditers, $countcase); #say $tee "IN DEFFILES \%mids" . dump( %mids );
 
+	if ( $dirfiles{starsign} eq "yes" )
+	{
+		%mids = %{ $starmids_ref };
+	}
+
 	my $rootitem = "$file" . "_"; #say $tee "IN DEFFILES \$rootitem : " . dump( $rootitem );
 	my (@basket, @box);
 	push (@basket, [ $rootitem ] ); #say $tee "IN DEFFILES \@basket : " . dump( @basket );
 
+	if ( $dirfiles{starsign} eq "yes" )
+	{
+		@blockelts = @{ $dummyblockelts_ref };
+	}
+
+
 	foreach my $var ( @blockelts )
 	{
 		my @bucket;
@@ -1227,9 +1294,9 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN SETLAUNCH \%dowhat" . dump( %dowhat );
 
 	my $rootname = getrootname(\@rootnames, $countcase);
-	( my $blockelts_ref, my $sweeps_ref, $dirfiles{shadowdirection} ) = getblockelts(\@sweeps, \%dirfiles, $countcase, $countblock );
+	my ( $blockelts_ref ) = getblockelts(\@sweeps, $countcase, $countblock );
 	my @blockelts = @{ $blockelts_ref };
-	@sweeps = @{ $sweeps_ref };
+
 
 	my @blocks = getblocks(\@sweeps, $countcase); #say $tee "IN SETLAUNCH \@blocks " . dump( @blocks );
 	my $toitem = getitem(\@winneritems, $countcase, $countblock);
@@ -1485,7 +1552,7 @@ sub opt
 	print "\nNow in Sim::OPT. \n";
 	$dowhat{file} = $file;
 
-  if ( $dowhat{randomsweeps} eq "yes" ) #IT SHUFFLES  @sweeps UNDER REQUEST SETTING.
+  if ( $dowhat{randomsweeps} eq "yes" ) #IT SHUFFLES  @sweeps UNDER REQUESTED SETTING.
   {
     my @newsweeps;
     foreach my $arrayref ( @sweeps )
@@ -1501,14 +1568,14 @@ sub opt
         }
         push ( @newsweeps, [ @newarr ] );
       }
-      @sweeps = @newsweeps;sub opt
+      @sweeps = @newsweeps;
       #print "NEW SWEEPS: " . dump( @sweeps ) . "\n";
   }
 
   my $i = 0;
   my @newarr;
   if ( $dowhat{randomdirs} eq "yes" )
-  { #IT SHUFFLES  $dowhat{direction} UNDER APPROPRIATE SETTINGS.
+  { #IT SHUFFLES  $dowhat{direction} UNDER REQUESTED SETTINGS.
     foreach my $directionref ( @{ $dowhat{direction} } )
     {
       my @varnumber = %{ $varnumbers[$i] };
@@ -1533,7 +1600,7 @@ sub opt
   }
 
 
-  { #IT FILLS THE MISSING $dowhat{direction} UNDER APPROPRIATE SETTINGS.
+  { #IT FILLS THE MISSING $dowhat{direction} UNDER REQUESTED SETTINGS.
     my $i = 0;
     my @newarr;
     foreach my $dirref ( @{ $dowhat{direction} } )
@@ -1556,7 +1623,7 @@ sub opt
     }
 		#say "112-0 \@newarr: " . dump( @newarr );
     $dowhat{direction} = [ @newarr ];
-    #say "NEW FILLED DIRECTIONS: " .sub opt dump( $dowhat{direction} );
+    #say "NEW FILLED DIRECTIONS: " . dump( $dowhat{direction} );
   }
 	#say "112-0 \$dowhat{direction}: " . dump( $dowhat{direction} );
 
@@ -1738,7 +1805,7 @@ sub opt
 				@sweeps = @sweepz;
 			}
 
-			@calcoverlaps = calcoverlaps( @sweeps ); #DDD
+			@calcoverlaps = calcoverlaps( @sweeps );
 
 	    #@miditers = @pinmiditers;
 			#my %mids = getcase( \@miditers, $countcase ); #say $tee "IN CALLCASE \%mids" . dump( %mids );
@@ -1757,6 +1824,8 @@ sub opt
 			$dirfiles{tottot} = "$mypath/$file-$countcase" . "-tottot.csv"; #say "IN CALLBLOCK tottot:" . ( $dirfiles{tottot} ) . " .";
 			$dirfiles{ordtot} = "$mypath/$file-$countcase" . "-ordtot.csv"; #say "IN CALLBLOCK ordtot:" . ( $dirfiles{ordtot} ) . " .";
 
+
+
 			callblock( { countcase => $countcase, rootnames => \@rootnames, countblock => $countblock,
 				miditers => \@miditers, varnumbers => \@varnumbers, winneritems => \@winneritems, sweeps => \@sweeps,
 				sourcesweeps => \@sourcesweeps, datastruc => \%datastruc, dirfiles => \%dirfiles,
@@ -1775,7 +1844,8 @@ sub opt
 			}
 
 			#@calcoverlaps = calcoverlaps( @sweeps );
-
+			$dirfiles{tottot} = "$mypath/$file-$countcase" . "-tottot.csv"; #say "IN CALLBLOCK tottot:" . ( $dirfiles{tottot} ) . " .";
+			$dirfiles{ordtot} = "$mypath/$file-$countcase" . "-ordtot.csv"; #say "IN CALLBLOCK ordtot:" . ( $dirfiles{ordtot} ) . " .";
 			#@miditers = @pinmiditers;
 			#say $tee "miditers: " . dump ( @miditers );
 
@@ -1817,7 +1887,7 @@ sub opt
 	close(OUTFILE);
 	close(TOFILE);
 	exit;
-} # END
+} # ENDsub opt
 
 #############################################################################
 
