@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend ); # our @EXPORT = qw( );
 
-$VERSION = '0.73'; # our $VERSION = '';
+$VERSION = '0.75'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -108,9 +108,8 @@ sub descend
     exit(say $tee "#END RUN.");
   }
 
-  ( my $blockelts_ref, my $sweeps_ref, $dirfiles{shadowdirection} ) = Sim::OPT::getblockelts(\@sweeps, \%dirfiles, $countcase, $countblock );
+  ( my $blockelts_ref ) = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock );
 	my @blockelts = @{ $blockelts_ref }; say $tee "IN ENTRY DESCEND \@blockelts : " . dump( @blockelts );
-	@sweeps = @{ $sweeps_ref }; #say $tee "IN ENTRY DESCEND \@sweeps : " . dump( @sweeps );
 
 	my @blocks = Sim::OPT::getblocks( \@sweeps, $countcase ); #say $tee "IN ENTRY DESCEND \@blocks : " . dump( @blocks );
 	my $toitem = Sim::OPT::getitem( \@winneritems, $countcase, $countblock ); #say $tee "IN ENTRY DESCEND \$toitem : " . dump( $toitem );
@@ -136,13 +135,13 @@ sub descend
   #say $tee "IN ENTRY DESCEND \$direction : " . dump( $direction ); #NEW
   #say $tee "IN ENTRY DESCEND \$starorder : " . dump( $starorder ); #NEW
 
-  my $precomputed = $dowhat{precomputed}; #say $tee "IN DESCEND \$precomputed: " . dump($precomputed); #NEW
+  my $precomputed = $dowhat{precomputed}; say $tee "IN DESCEND \$precomputed: " . dump($precomputed); #NEW
   my @takecolumns = @{ $dowhat{takecolumns} }; #NEW
   my @starpositions = @{ $dowhat{starpositions} }; #say $tee "IN ENTRY DESCEND \@starpositions : " . dump( @starpositions );
   my $starnumber = scalar( @starpositions ); #say $tee "IN ENTRY DESCEND \$starnumber : " . dump( $starnumber );
   my $starobjective = $dowhat{starobjective}; #say $tee "IN ENTRY DESCEND \$starobjective : " . dump( $starobjective );
   my $objectivecolumn = $dowhat{objectivecolumn}; #say $tee "IN ENTRY DESCEND \$objectivecolumn : " . dump( $objectivecolumn );
-  my $searchname = $dowhat{searchname};
+  my $searchname = $dowhat{searchname}; say $tee "IN ENTRY DESCEND \$searchname: " . dump( $searchname );
 
   my $countstring = $dirfiles{countstring}; #say $tee "IN ENTRY DESCEND \$countstring: " . dump( $countstring );
   my $starstring = $dirfiles{starstring}; #say $tee "IN ENTRY DESCEND \$starstring: " . dump( $starstring );
@@ -820,179 +819,196 @@ sub descend
 
     if ( $countblock == $#blocks )
     {
-      open( TOTRES, "$totres" ) or die;
-      my @lins = <TOTRES>;
-      close TOTRES;
-
-      my @lins = uniq( @lins );
-      my @sorted;
-      if ( $direction ne "star" )
+      if ( ( ( $dirfiles{starsign} eq "yes" ) and ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
+              and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
+            or ( ( $dirfiles{starsign} ne "yes" ) ) )
       {
-        if ( $direction eq "<" )
-        {
-          @sorted = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lins;
-        }
-        elsif ( $direction eq ">" )
-        {
-          @sorted = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lins;
-        }
-        else
-        {
-          say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
-        }
-      }
-      elsif ( $direction eq "star" )
-      {
-        if ( $starorder eq "<" )
-        {
-          @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @lins;
-        }
-        elsif ( $starorder eq ">" )
-        {
-          @sorted = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @lins;
-        }
-        else
-        {
-          say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
-        }
-      }
 
 
-      open( ORDRES, ">$ordres" ) or die;
+        open( TOTRES, "$totres" ) or die;
+        my @lins = <TOTRES>;
+        close TOTRES;
 
-      foreach my $lin ( @sorted )
-      {
-        print ORDRES $lin;
-      }
-      close ORDRES;
+        my @lins = uniq( @lins );
+        my @sorted;
+        if ( $direction ne "star" )
+        {
+          if ( $direction eq "<" )
+          {
+            @sorted = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lins;
+          }
+          elsif ( $direction eq ">" )
+          {
+            @sorted = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lins;
+          }
+          else
+          {
+            say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+          }
+        }
+        elsif ( $direction eq "star" )
+        {
+          if ( $starorder eq "<" )
+          {
+            @sorted = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @lins;
+          }
+          elsif ( $starorder eq ">" )
+          {
+            @sorted = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @lins;
+          }
+          else
+          {
+            say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+          }
+        }
 
 
-      if ( ( scalar( @starpositions > 0) ) and ( $countstring ) )
-      {
-        open( ORDRES, "$ordres" ) or die;
-        my @ordlines = <ORDRES>;
+        open( ORDRES, ">$ordres" ) or die;
+
+        foreach my $lin ( @sorted )
+        {
+          print ORDRES $lin;
+        }
         close ORDRES;
 
-        open( TOTTOT, ">>$tottot" ) or die;
-        foreach my $line ( @ordlines )
-        {
-          print TOTTOT $line;
-        }
-        close TOTTOT;
 
-        if ( $countstring == $starnumber )
+        if ( ( scalar( @starpositions > 0) ) and ( $countstring ) )
         {
-          open( TOTTOT, "$tottot" ) or die;
-          my @totlines = <TOTTOT>;
+          open( ORDRES, "$ordres" ) or die;
+          my @ordlines = <ORDRES>;
+          close ORDRES;
+
+          open( TOTTOT, ">>$tottot" ) or die;
+          foreach my $line ( @ordlines )
+          {
+            print TOTTOT $line;
+          }
           close TOTTOT;
 
+          if ( $countstring == $starnumber )
+          {
+            open( TOTTOT, "$tottot" ) or die;
+            my @totlines = <TOTTOT>;
+            close TOTTOT;
 
-          my @lns = uniq( @totlines );
-          my @sortedln;
-          if ( $direction ne "star" )
-          {
-            if ( $direction eq "<" )
+
+            my @lns = uniq( @totlines );
+            my @sortedln;
+            if ( $direction ne "star" )
             {
-              @sortedln = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lns;
+              if ( $direction eq "<" )
+              {
+                @sortedln = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lns;
+              }
+              elsif ( $direction eq ">" )
+              {
+                @sortedln = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lns;
+              }
+              else
+              {
+                say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+              }
             }
-            elsif ( $direction eq ">" )
+            elsif ( $direction eq "star" )
             {
-              @sortedln = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lns;
+              if ( $starorder eq "<" )
+              {
+                @sortedln = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @lns;
+              }
+              elsif ( $starorder eq ">" )
+              {
+                @sortedln = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @lns;
+              }
+              else
+              {
+                say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+              }
             }
-            else
+
+
+            open( ORDTOT, ">$ordtot" ) or die;
+            foreach my $ln ( @sortedln )
             {
-              say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+              print ORDTOT $ln;
             }
+            close ORDTOT;
           }
-          elsif ( $direction eq "star" )
+        }
+
+        #say $tee "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
+        my @morphcases = grep -d, <$mypath/$file_*>;
+        unless ( $direction eq "star" )
+        {
+          say $tee "#Optimal option for case " . ( plus1( $countcase ) ) . ": $newtarget.";
+        }
+        #my $instnum = Sim::OPT::countarray( @{ $morphstruct[$countcase] } );
+
+        #my $netinstnum = scalar( @morphcases );
+        @totalcases = uniq( @totalcases );
+        my $netinstnum = scalar( @totalcases );
+
+        say $tee "#Net number of instances: $netinstnum." ;
+        open( RESPONSE , ">>$mypath/response.txt" );
+        unless ( $direction eq "star" )
+        {
+          say RESPONSE "#Optimal option for case " . ( plus1( $countcase ) ) . ": $newtarget.";
+        }
+
+        if ( $starstring eq "" )
+        {
+          say "NOT DOING";
+          say RESPONSE "#Net number of instances: $netinstnum.\n" ;
+        }
+        elsif ( $starstring ne "" )
+        {
+          my @lines = uniq( @lines );
+          if ( ( $starorder = ">" ) or ( $direction = ">" ) )
           {
-            if ( $starorder eq "<" )
-            {
-              @sortedln = sort { (split( ',', $a))[ 0 ] <=> ( split( ',', $b))[ 0 ] } @lns;
-            }
-            elsif ( $starorder eq ">" )
-            {
-              @sortedln = sort { (split( ',', $b))[ 0 ] <=> ( split( ',', $a))[ 0 ] } @lns;
-            }
-            else
-            {
-              say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
-            }
+            #say "DOING_1a";
+            @lines = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lines;
+          }
+          elsif ( ( $starorder = "<" ) or ( $direction = "<" ) )
+          {
+            #say "DOING_1b";
+            @lines = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lines;
+          }
+          else
+          {
+            say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
           }
 
-
-          open( ORDTOT, ">$ordtot" ) or die;
-          foreach my $ln ( @sortedln )
-          {
-            print ORDTOT $ln;
-          }
-          close ORDTOT;
-        }
-      }
-
-      #say $tee "TAKEOPTIMA FINAL ->\$countblock " . dump($countblock);
-      my @morphcases = grep -d, <$mypath/$file_*>;
-      unless ( $direction eq "star" )
-      {
-        say $tee "#Optimal option for case " . ( plus1( $countcase ) ) . ": $newtarget.";
-      }
-      #my $instnum = Sim::OPT::countarray( @{ $morphstruct[$countcase] } );
-
-      #my $netinstnum = scalar( @morphcases );
-      @totalcases = uniq( @totalcases );
-      my $netinstnum = scalar( @totalcases );
-
-      say $tee "#Net number of instances: $netinstnum." ;
-      open( RESPONSE , ">>$mypath/response.txt" );
-      unless ( $direction eq "star" )
-      {
-        say RESPONSE "#Optimal option for case " . ( plus1( $countcase ) ) . ": $newtarget.";
-      }
-
-      if ( $starstring eq "" )
-      {
-        say "NOT DOING";
-        say RESPONSE "#Net number of instances: $netinstnum.\n" ;
-      }
-      elsif ( $starstring ne "" )
-      {
-        my @lines = uniq( @lines );
-        if ( ( $starorder = ">" ) or ( $direction = ">" ) )
-        {
-          #say "DOING_1a";
-          @lines = sort { (split( ',', $b))[ $objectivecolumn ] <=> ( split( ',', $a))[ $objectivecolumn ] } @lines;
-        }
-        elsif ( ( $starorder = "<" ) or ( $direction = "<" ) )
-        {
-          #say "DOING_1b";
-          @lines = sort { (split( ',', $a))[ $objectivecolumn ] <=> ( split( ',', $b))[ $objectivecolumn ] } @lines;
-        }
-        else
-        {
-          say $tee "THE OBJECTIVE IS NOT CLEAR IN THE \%dowhat PARAMETER OF THE CONFIGURATION FILE.";
+          my $num = scalar( @lines );
+          say RESPONSE "#Net number of instances: $num.\n" ;
         }
 
-        my $num = scalar( @lines );
-        say RESPONSE "#Net number of instances: $num.\n" ;
+        say RESPONSE "Order of the parameters: " . dump( @sweeps );
+        say RESPONSE "Number of parameter levels: " . dump( @varnumbers );
+        say RESPONSE "Last initialization level: " . dump( @miditers );
+        say RESPONSE "Descent directions: " . dump( $dowhat{direction} );
+
+        $countblock = 0;
+        $countcase++; ####!!!
+        $countstring++;
+        $dirfiles{countstring} = $countstring;
+
+        push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
+        say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
+
+
       }
 
-      say RESPONSE "Order of the parameters: " . dump( @sweeps );
-      say RESPONSE "Number of parameter levels: " . dump( @varnumbers );
-      say RESPONSE "Last initialization level: " . dump( @miditers );
-      say RESPONSE "Descent directions: " . dump( $dowhat{direction} );
 
-      $countblock = 0;
-      $countcase++;
-      $countstring++;
-      $dirfiles{countstring} = $countstring;
 
-      push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
-      say $tee "#Leaving case $countcase. Beginning with case " . ( plus1( $countcase ) ) . ".";
-
-      if ( $dowhat{shadowdirection} eq "yes" )
+      if ( ( $dirfiles{starsign} eq "yes" ) and ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
+          and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
       {
         @varnumbers = @{ dclone( \@{ $dowhat{varnumbershold} } ) };
-        $dowhat{shadowdirection} eq "no";
+        $dirfiles{starsign} = "no";
+        $countblock++; ### !!!
+      }
+      elsif ( $dirfiles{starsign} ne "yes" )
+      {
+        $countblock++; ### !!!
       }
 
       Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
@@ -1006,9 +1022,6 @@ sub descend
       push ( @{ $winneritems[$countcase][$countblock] }, $winneritem ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
       say $tee "#Leaving case " . ( plus1 ( $countcase ) ) . ", block " . ( plus1 ( $countcase ) ) . ", and descending!";
 
-
-      $countblock++; ### !!!
-
       #say $tee "\$countcase : " . dump( $countcase );
       #say $tee "\$countblock : " . dump( $countblock );
       #say $tee "\@miditers : " . dump( @miditers );
@@ -1021,10 +1034,19 @@ sub descend
       #say $tee "\%datastruc : " . dump( %datastruc );
       #say $tee "\%dowhat : " . dump( %dowhat );
 
-      if ( $dowhat{shadowdirection} eq "yes" )
+      if ( $dirfiles{starsign} eq "yes" )
       {
-        @varnumbers = @{ dclone( \@{ $dowhat{varnumbershold} } ) };
-        $dowhat{shadowdirection} eq "no";
+        if ( ( $dirfiles{d} == scalar( @{ $dirfiles{starpositions} } ) )
+          and ( $dirfiles{c} == scalar( @{ $dirfiles{dummyblockelts} } ) ) )
+        {
+          @varnumbers = @{ dclone( \@{ $dowhat{varnumbershold} } ) };
+          $dirfiles{starsign} = "no";
+          $countblock++; ### !!!
+        }
+      }
+      else
+      {
+        $countblock++; ### !!!
       }
 
       Sim::OPT::callblock( { countcase => $countcase, countblock => $countblock,
@@ -1033,7 +1055,7 @@ sub descend
       sweeps => \@sweeps, datastruc => \%datastruc, dowhat => \%dowhat,
       sourcesweeps => \@sourcesweeps, } )
     }
-  }
+  } # END SUB takeoptima
 
   takeoptima( $sortmixed ); say $tee "TAKEOPTIMA \$sortmixed : " . dump( $sortmixed );
   close OUTFILE;
